/**
 *   @file  csl_mpuGetBaseAddress.c
 *
 *   @brief   
 *      The file contains routines which are MPU Device specific
 *      and need to be modified for each new device which has the 
 *      MPU IP Module.
 *
 *  \par
 *  ============================================================================
 *  @n   (C) Copyright 2012, Texas Instruments, Inc.
 *  @n   Use of this software is controlled by the terms and conditions found 
 *  @n   in the license agreement under which this software has been supplied.
 *  ===========================================================================
 *  \par
 */

#include <ti/csl/soc.h>
#include <ti/csl/csl_mpu.h>

/** ============================================================================
 *   @n@b CSL_MPU_Open
 *
 *   @b Description
 *   @n This API opens the MPU instance. This should always be the first call 
 *      to the CSL MPU Functional layer. The handle  which is returned from 
 *      this call should be passed in all subsequent CSL API's.
 *      
 *   <b> Return Value </b> 
 *   @n  CSL_MpuHandle  - Handle to the MPU Module
 *   @n  0               - Error. 
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  None  
 *
 *   @b  Affects
 *   @n  None.
 *
 *   @b  Example
 *   @verbatim
        CSL_MpuHandle   hMpu;
        ...
        hMpu = CSL_MPU_Open (0);    // Opens MPU Instance 0
        ...
     @endverbatim
 * ===========================================================================
 */
CSL_MpuHandle CSL_MPU_Open (Int32 instNum)
{
    switch (instNum)
    {
#ifdef CSL_MPU_0
        case CSL_MPU_0:
        {
            return (CSL_MpuHandle)CSL_MPU_0_REGS;
        }
#endif /* CSL_MPU_0 */
#ifdef CSL_MPU_1
        case CSL_MPU_1:
        {
            return (CSL_MpuHandle)CSL_MPU_1_REGS;
        }
#endif /* CSL_MPU_1 */
#ifdef CSL_MPU_2
        case CSL_MPU_2:
        {
            return (CSL_MpuHandle)CSL_MPU_2_REGS;
        }
#endif /* CSL_MPU_2 */
#ifdef CSL_MPU_3
        case CSL_MPU_3:
        {
            return (CSL_MpuHandle)CSL_MPU_3_REGS;
        }
#endif /* CSL_MPU_3 */
#ifdef CSL_MPU_4
        case CSL_MPU_4:
        {
            return (CSL_MpuHandle)CSL_MPU_4_REGS;
        }
#endif /* CSL_MPU_4 */
#ifdef CSL_MPU_5
        case CSL_MPU_5:
        {
            return (CSL_MpuHandle)CSL_MPU_5_REGS;
        }
#endif /* CSL_MPU_5 */
#ifdef CSL_MPU_6
        case CSL_MPU_6:
        {
            return (CSL_MpuHandle)CSL_MPU_6_REGS;
        }
#endif /* CSL_MPU_6 */
#ifdef CSL_MPU_7
        case CSL_MPU_7:
        {
            return (CSL_MpuHandle)CSL_MPU_7_REGS;
        }
#endif /* CSL_MPU_7 */
#ifdef CSL_MPU_8
        case CSL_MPU_8:
        {
            return (CSL_MpuHandle)CSL_MPU_8_REGS;
        }
#endif /* CSL_MPU_8 */
#ifdef CSL_MPU_9
        case CSL_MPU_9:
        {
            return (CSL_MpuHandle)CSL_MPU_9_REGS;
        }
#endif /* CSL_MPU_9 */
#ifdef CSL_MPU_10
        case CSL_MPU_10:
        {
            return (CSL_MpuHandle)CSL_MPU_10_REGS;
        }
#endif /* CSL_MPU_10 */
#ifdef CSL_MPU_11
        case CSL_MPU_11:
        {
            return (CSL_MpuHandle)CSL_MPU_11_REGS;
        }
#endif /* CSL_MPU_11 */
#ifdef CSL_MPU_12
        case CSL_MPU_12:
        {
            return (CSL_MpuHandle)CSL_MPU_12_REGS;
        }
#endif /* CSL_MPU_12*/
#ifdef CSL_MPU_13
        case CSL_MPU_13:
        {
            return (CSL_MpuHandle)CSL_MPU_13_REGS;
        }
#endif /* CSL_MPU_13 */
#ifdef CSL_MPU_14
        case CSL_MPU_14:
        {
            return (CSL_MpuHandle)CSL_MPU_14_REGS;
        }
#endif /* CSL_MPU_14 */
#ifdef CSL_MPU_15
        case CSL_MPU_15:
        {
            return (CSL_MpuHandle)CSL_MPU_15_REGS;
        }
#endif /* CSL_MPU_15 */
        default:
        {
            return (CSL_MpuHandle)0;
        }
    }
}

