/******************************************************************************
 * FILE PURPOSE: QMSS Source module specification file.
 ******************************************************************************
 * FILE NAME: module.xs
 *
 * DESCRIPTION: 
 *  This file contains the module specification for the QMSS source directory.
 *
 * Copyright (C) 2009-2014, Texas Instruments, Inc.
 *****************************************************************************/

/* Load the library utility. */
var libUtility = xdc.loadCapsule ("../build/buildlib.xs");

var qmsslldFile = [
    "src/qmss_drv.c",
    "src/qmss_acc.c",
    "src/qmss_qos.c",
    "src/qmss_qosSched.c",
    "src/qmss_srioRtr.c"
];

/**************************************************************************
 * FUNCTION NAME : modBuild
 **************************************************************************
 * DESCRIPTION   :
 *  The function is used to build all the components of the QMSS library
 **************************************************************************/
function modBuild() 
{
    for (var device=0; device < devices.length; device++) 
    {
        var targetFiles = qmsslldFile.slice(); /* make copy */
        if (device != 0)
        {
           /* extract device without c66 suffix */
           var dev=devices[device];
           var idx = dev.indexOf("/");
           dev = dev.substr(0,idx);
           targetFiles.push (deviceConstruct[0]+dev+deviceConstruct[1]);
        }
        /* Build the libraries for all the targets specified. */
        for (var targets=0; targets < Build.targets.length; targets++)
        {
            var libOptions = {
                copts: devicesCCOpt[device],
                incs: lldIncludePath, 
            };
       
            libUtility.buildLibrary (devices[device], libOptions, "ti.drv.qmss", Build.targets[targets], targetFiles);
        }
    }

    /* Add all the .c files to the release package. */
    var testFiles = libUtility.listAllFiles (".c", "src", true);
    for (var k = 0 ; k < testFiles.length; k++)
        Pkg.otherFiles[Pkg.otherFiles.length++] = testFiles[k];

    /* Add all the .h files to the release package. */
    var testFiles = libUtility.listAllFiles (".h", "src", true);
    for (var k = 0 ; k < testFiles.length; k++)
        Pkg.otherFiles[Pkg.otherFiles.length++] = testFiles[k];
}

