/**
 *   @file  fault_mgmt.h
 *
 *   @brief
 *      Header file for the Fault Management library. The file exposes the 
 *      data structures and exported API which are available for use by 
 *      applications.
 *
 *  \par
 *  NOTE:
 *      (C) Copyright 2012 Texas Instruments, Inc.
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

 
/** @defgroup FAULT_MGMT_API   Fault Management
 */

#ifndef __FAULT_MGMT_H__
#define __FAULT_MGMT_H__

/* BIOS Exception include file */
#include <ti/sysbios/family/c64p/Exception.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
@defgroup FAULT_MGMT_SYMBOL                  Fault Management Defined Symbols
@ingroup FAULT_MGMT_API
*/
/**
@defgroup FAULT_MGMT_FUNCTION                Fault Management Functions
@ingroup FAULT_MGMT_API
*/
/**
@defgroup FAULT_MGMT_DATA_STRUCTURE          Fault Management Data Structures
@ingroup FAULT_MGMT_API
*/
/**
@defgroup FAULT_MGMT_OSAL_API                Fault Management OSAL API
@ingroup FAULT_MGMT_API
*/

/** @addtogroup FAULT_MGMT_SYMBOL
 @{ */

/**
 * @brief 
 *  Size of memory used by the fault management library to copy any data that will be sent to the fault 
 *  handling module.
 */
#define FAULT_MGMT_DATA_SIZE                 1024

/**
 * @brief 
 *  Number of cores to be notified when an exception occurs, including the core where the exception
 *  happens.
 */
#define FAULT_MGMT_NOTIFY_NUM_CORES            8

/**
 * @brief
 *  Fault interrupt to Host is above the bits used by regular IPC. This is the offset to be used for setting
 *  the IPCGRH register bit
 */
#define FAULT_MGMT_HOST_IPCGR_OFFSET            8
/**
@}
*/

/**********************************************************************
 ****************** EXPORTED DATA STRUCTURES **************************
 **********************************************************************/

extern uint8_t     fault_mgmt_data[FAULT_MGMT_DATA_SIZE];



/**********************************************************************
 **************************** EXPORTED API ****************************
 **********************************************************************/

extern void Fault_Mgmt_getLastRegStatus(void);
extern void Fault_Mgmt_notify(void);
extern void Fault_Mgmt_notify_remote_core(uint32_t core_id);

/**
@}
*/

#ifdef __cplusplus
}
#endif

#endif /* __FAULT_MGMT_H__ */

